@@ -1,18 +1,14 @@
 # -*- coding: utf-8 -*-
 import inspect
-import logging
 
 from declic import Command as DeclicCommand
 from declic import Group
 from outflow.core.generic.metaclasses import Singleton
 from outflow.core.generic.string import to_camel_case, to_snake_case
+from outflow.core.logging import logger
 from outflow.core.pipeline import context
-from outflow.core.plugin import get_plugin_name
-from outflow.core.target import Target
 from outflow.core.tasks import Task
-from outflow.library.tasks import PipelineArgs
-
-logger = logging.getLogger(__name__)
+from outflow.library.tasks.pipeline_args import PipelineArgs
 
 
 class Command(Group, metaclass=Singleton):
@@ -120,7 +116,6 @@ class Command(Group, metaclass=Singleton):
         """
 
         with_task_context = kwargs.pop("with_task_context", False)
-        plugin_name = get_plugin_name()
 
         def decorator(callback_or_command_class):
             is_class = inspect.isclass(callback_or_command_class)
@@ -154,20 +149,37 @@ class Command(Group, metaclass=Singleton):
                 def setup_tasks(self):
                     pipeline_args = PipelineArgs()
 
-                    @Target.output(
-                        "None"
-                    )  # workaround to avoid automatic output declaration
-                    @Task.as_task(
-                        name=subclass_name,
-                        with_self=with_task_context,
-                        plugin_name=plugin_name,
-                    )
-                    def InnerTask(*args, **kwargs):
-                        self.outputs = {}  # revert workaround to have normal behaviour
-                        if args:
-                            kwargs.update({"self": args[0]})
-                        # filter task kwargs using subcommand keywords
-                        return self.generic_callback(kwargs, callback_or_command_class)
+                    command_self = self
+
+                    class InnerTask(Task):
+                        def __init_subclass__(cls, **kwargs):
+                            cls.with_self = with_task_context
+                            super().__init_subclass__(**kwargs)
+
+                        def __init__(self, **kwargs):
+                            super().__init__(
+                                **kwargs,
+                                name=subclass_name,
+                            )
+
+                        def setup_targets(self):
+                            pass
+
+                        def add_upstream(self, upstream_block: "Block"):
+                            self.inputs.update(upstream_block.outputs)
+                            super().add_upstream(upstream_block)
+
+                        def run(self, *args, **kwargs):
+
+                            self.outputs = (
+                                {}
+                            )  # revert workaround to have normal behaviour
+                            if args:
+                                kwargs.update({"self": args[0]})
+                            # filter task kwargs using subcommand keywords
+                            return command_self.generic_callback(
+                                kwargs, callback_or_command_class
+                            )
 
                     task = InnerTask()
                     pipeline_args >> task
@@ -182,8 +194,27 @@ class Command(Group, metaclass=Singleton):
             kwargs.setdefault("backend", self.backend)
             if name:
                 SubClass.__name__ = name
+            SubClass.__doc__ = callback_or_command_class.__doc__
             cmd = SubClass(*args, parent=self, **kwargs)
             self.add_command(cmd)
             return SubClass
 
         return decorator
+
+    @property
+    def full_name(self):
+        """
+        Returns the fully qualified command name
+        """
+
+        full_name = [self.name]
+
+        command = self
+
+        while command.parent and command.parent.name != "root_command":
+            full_name.append(command.parent.name)
+            command = command.parent
+
+        full_name.reverse()
+
+        return " ".join(full_name)
