@@ -3,13 +3,10 @@
 
 
 import json
-import logging
 
 from sqlalchemy import Column, ForeignKey
 from sqlalchemy.dialects.postgresql import ENUM
 
-logger = logging.getLogger("sqlalchemy")
-
 __all__ = ["NonNullColumn"]
 
 
