@@ -16,3 +16,7 @@ class Singleton(type):
         cls.instance = super(Singleton, cls).__call__(*args, **kwargs)
 
         return cls.instance
+
+    def reset(cls):
+        del cls.instance
+        cls.instance = None
