@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 class NullObject:
-    """ Null objects always and reliably "do nothing." """
+    """Null objects always and reliably "do nothing." """
 
     # TODO probably replace with magic mock
 
@@ -27,3 +27,7 @@ class NullObject:
 
     def __getitem__(self, item):
         return self
+
+    def __iter__(self):
+        for n in []:
+            yield n
