@@ -23,3 +23,9 @@ class OutflowFormatter(logging.Formatter):
         text = super().format(record)
 
         return text
+
+
+class OutflowFileFormatter(OutflowFormatter):
+
+    base_format = "%(asctime)s - %(levelname)s - [%(name)s] %(message)s"
+    remote_format = "%(asctime)s - %(levelname)s - (%(ip)s) [%(name)s]  %(message)s"
