@@ -13,5 +13,8 @@ config.set_factory(Config.resolve_lazy_object)
 context.set_factory(PipelineContext)
 settings.set_factory(Settings.resolve_lazy_object)
 
-from .pipeline import set_pipeline_state  # noqa: F401, E402
-from .pipeline import Pipeline, get_pipeline_states  # noqa: F401, E402
+from .pipeline import (  # noqa: F401, E402
+    Pipeline,
+    get_pipeline_states,
+    set_pipeline_state,
+)
