@@ -4,6 +4,8 @@ Default Outflow settings. Override these with settings in the module pointed to
 by the OUTFLOW_SETTINGS_MODULE environment variable.
 """
 import os
+import pathlib
+import tempfile
 
 from outflow.core.commands import RootCommand
 
@@ -22,3 +24,5 @@ BACKENDS = {
 }
 
 ROOT_COMMAND_CLASS = RootCommand
+
+TEMP_DIR = pathlib.Path(tempfile.gettempdir()) / "outflow_tmp"
