@@ -23,6 +23,7 @@ class PipelineContext(ManagedClass, context_manager=PipelineContextManager):
         self.map_uuid = ""
         self.run_uuid = ""
         self.running_slurm_job_ids = []
+        self.overwrite_cache: bool = False
 
         # store each plugin models to allow metadata clear/backup
         self._models = None
@@ -47,7 +48,7 @@ class PipelineContext(ManagedClass, context_manager=PipelineContextManager):
 
     @property
     def session(self):
-        if self.db_untracked or self.dry_run:
+        if self.dry_run:
             return NullObject()
 
         if self._models is None:
