@@ -1,4 +1,6 @@
 # -*- coding: utf-8 -*-
+import pathlib
+
 import pytest
 from outflow.core.commands import RootCommand
 from outflow.core.pipeline import Pipeline, context, settings
@@ -54,6 +56,7 @@ class CommandTestCase:
     @pytest.fixture(autouse=True)
     def setup_within_pipeline_context(self, with_pipeline_context_manager):
         settings.PLUGINS = self.PLUGINS
+        settings.TEMP_DIR = pathlib.Path(__file__).parent.resolve() / ".outflow_tmp"
 
     @pytest.fixture(autouse=True)
     def with_pipeline_context_manager(self):
@@ -64,16 +67,19 @@ class CommandTestCase:
     def teardown_method(self):
         pass
 
-    def run_command(self, arg_list=[], force_dry_run=True, **kwargs):
+    def run_command(self, arg_list=[], force_dry_run=None, **kwargs):
         settings.ROOT_COMMAND_CLASS = (
             RootCommand if self.root_command_class is None else self.root_command_class
         )
 
+        if force_dry_run is not None:
+            self.force_dry_run = force_dry_run
+
         with Pipeline(
             root_directory=None,
             settings_module=None,
             argv=arg_list,
-            force_dry_run=force_dry_run,
+            force_dry_run=self.force_dry_run,
             **kwargs
         ) as pipeline:
 
