@@ -2,7 +2,7 @@
 import pytest
 from outflow.core.pipeline import context
 from outflow.core.pipeline.context_manager import PipelineContextManager
-from outflow.core.workflow import WorkflowManager
+from outflow.core.workflow import Workflow
 
 
 class TaskTestCase:
@@ -50,7 +50,7 @@ class TaskTestCase:
         with PipelineContextManager():
             context.db_untracked = True
             context.force_dry_run = True
-            with WorkflowManager():
+            with Workflow():
                 yield
 
     def setup_method(self):
@@ -69,4 +69,4 @@ class TaskTestCase:
         if self.task is None:
             raise ValueError("The task has not been initialized")
 
-        return self.task(*args, **kwargs)
+        return self.task(*args, block_db=None, **kwargs)
