@@ -12,19 +12,22 @@ class IdentityTask(Task):
     TODO: Change the name of this task because it is not really an "identity" as we are allowed to mutate kwargs
     """
 
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, auto_outputs=False, **kwargs)
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
 
-    def add_parent(self, parent_task):
-        super().add_parent(parent_task)
-        self.copy_targets(parent_task)
+    def setup_targets(self):
+        pass
 
-    def copy_targets(self, task):
-        self.inputs.update(task.outputs)
-        self.outputs.update(task.outputs)
+    def add_upstream(self, upstream_block: "Block"):
+        super().add_upstream(upstream_block)
+        self.copy_targets(upstream_block)
 
-    def __call__(self, *args, **kwargs):
-        return super().__call__(*args, **kwargs)
+    def copy_targets(self, block: "Block"):
+        self.inputs.update(block.outputs)
+        self.outputs.update(block.outputs)
+
+    # def __call__(self, *args, **kwargs):
+    #     return super().__call__(*args, **kwargs)
 
     def run(self, **kwargs):
         return kwargs
@@ -32,7 +35,7 @@ class IdentityTask(Task):
 
 class ConditionalTask(IdentityTask):
     def __init__(self, condition: Callable, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+        super().__init__(**kwargs)
         self._condition = condition
 
     def condition(self, **kwargs):
@@ -40,20 +43,20 @@ class ConditionalTask(IdentityTask):
 
 
 class ThenTask(ConditionalTask):
-    def run(self, *args, **kwargs):
+    def run(self, **kwargs):
         if not self.condition(**kwargs):
-            for child_task in self.children:
-                child_task.skip = True
-            self.db_task.success = self.db_task.skip
+            for downstream_block in self.downstream_blocks:
+                downstream_block.skip = True
+
         return super().run(**kwargs)
 
 
 class ElseTask(ConditionalTask):
     def run(self, **kwargs):
         if self.condition(**kwargs):
-            for child_task in self.children:
-                child_task.skip = True
-            self.db_task.success = self.db_task.skip
+            for downstream_block in self.downstream_blocks:
+                downstream_block.skip = True
+
         return super().run(**kwargs)
 
 
@@ -77,12 +80,12 @@ def IfThenElse(condition: Callable, name: str = "ConditionalTask"):
 
 
 class MergeTask(IdentityTask):
-    def __init__(self, *args, **kwargs):
-        super().__init__(*args, **kwargs)
+    def __init__(self, **kwargs):
+        super().__init__(**kwargs)
         self.skip_if_upstream_skip = False
 
     def __call__(self, *args, **kwargs):
-        if all(parent.skip for parent in self.parents):
+        if all(upstream.skip for upstream in self.upstream_blocks):
             self.skip = True
 
         return super().__call__(*args, **kwargs)
@@ -106,7 +109,8 @@ class MergeTask(IdentityTask):
 
         return stripped_return_dict
 
-    def check_inputs(self, task_inputs):
+    def check_inputs(self, task_inputs, values_from_upstream):
+        # TODO test if still working
 
         inputs_ok = []
         for output in self.outputs:
@@ -116,6 +120,9 @@ class MergeTask(IdentityTask):
 
         if len(inputs_ok) != len(task_inputs.items()):
             raise IOCheckerError(
-                f"Task {self.name} did not get all expected inputs: expected {[k for k in self.inputs.keys()]}, got "
-                f"{[k for k in task_inputs.keys()]}"
+                "Task {} did not get all expected inputs: expected {}, got {}".format(
+                    self.name,
+                    [k for k in self.inputs.keys()],
+                    {{**values_from_upstream, **task_inputs.keys()}},
+                )
             )
