@@ -6,9 +6,9 @@ from outflow.core.pipeline import Pipeline
 
 
 def entrypoint():
-    pipeline = Pipeline(
+    with Pipeline(
         root_directory=None,
-        settings_module="outflow.core.pipeline.settings_management.default_settings",
+        settings_module="outflow.core.pipeline.default_settings",
         force_dry_run=True,
-    )
-    return pipeline.run()
+    ) as pipeline:
+        return pipeline.run()
