@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-from sqlalchemy import Column, Integer, ForeignKey
+from sqlalchemy import Column, Integer, ForeignKey, String
 from sqlalchemy.orm import relationship
 
 from outflow.core.db import Model
@@ -16,3 +16,4 @@ class Run(Model, Executable):
     id = Column(Integer, primary_key=True)
     configuration_id = Column(Integer, ForeignKey(Configuration.id), nullable=False)
     configuration = relationship("Configuration", back_populates="runs")
+    command_name = Column(String, nullable=True)
