@@ -12,8 +12,8 @@ if __name__ == "__main__":
     # note: for cython like plugins, the compilation step is required and
     # plugin installation via pip is strongly encouraged
     plugins_dir = pathlib.Path(__file__).parent / "plugins"
-    if plugins_dir.is_dir():
-        for plugin_path in plugins_dir.glob("*"):
-            sys.path.append(plugin_path.resolve().as_posix())
-    pipeline = Pipeline(root_directory=pipeline_root_directory)
-    exit(pipeline.run())
+    for plugin_path in plugins_dir.glob("*"):
+        sys.path.append(plugin_path.resolve().as_posix())
+
+    with Pipeline(root_directory=pipeline_root_directory) as pipeline:
+        exit(pipeline.run())
